@@ -11,6 +11,7 @@ class TranscriptionStartSite:
     tx_ids = attr.ib()
     gene_id = attr.ib()
     ccds_id = attr.ib()
+    tx_types = attr.ib()
 
     def __str__(self):
         return "\t".join(
@@ -22,13 +23,14 @@ class TranscriptionStartSite:
                 " ".join(self.tx_ids),
                 self.gene_id,
                 str(self.ccds_id),  # is string or None
+                " ".join(self.tx_types),
             )
         )
 
 
 def get_header():
     return "\t".join(
-        ("tss_id", "chrom", "tss", "strand", "tx_ids", "gene_id", "ccds_id")
+        ("tss_id", "chrom", "tss", "strand", "tx_ids", "gene_id", "ccds_id", "tx_types")
     )
 
 
@@ -46,6 +48,7 @@ def load_transcription_start_sites(input_file):
                 line[4].split(),
                 line[5],
                 line[6],
+                line[7].split(),
             )
             TSSs.append(tss)
     return TSSs
